Class: Google::Cloud::ErrorReporting::V1beta1::QueryTimeRange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/devtools/clouderrorreporting/v1beta1/error_stats_service.rb

Overview

Requests might be rejected or the resulting timed count durations might be adjusted for lower durations.

Defined Under Namespace

Modules: Period

Instance Attribute Summary collapse

Instance Attribute Details

#period::Google::Cloud::ErrorReporting::V1beta1::QueryTimeRange::Period

Returns Restricts the query to the specified time range.

Returns:

  • Restricts the query to the specified time range.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'proto_docs/google/devtools/clouderrorreporting/v1beta1/error_stats_service.rb', line 235

class QueryTimeRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported time ranges.
  module Period
    # Do not use.
    PERIOD_UNSPECIFIED = 0

    # Retrieve data for the last hour.
    # Recommended minimum timed count duration: 1 min.
    PERIOD_1_HOUR = 1

    # Retrieve data for the last 6 hours.
    # Recommended minimum timed count duration: 10 min.
    PERIOD_6_HOURS = 2

    # Retrieve data for the last day.
    # Recommended minimum timed count duration: 1 hour.
    PERIOD_1_DAY = 3

    # Retrieve data for the last week.
    # Recommended minimum timed count duration: 6 hours.
    PERIOD_1_WEEK = 4

    # Retrieve data for the last 30 days.
    # Recommended minimum timed count duration: 1 day.
    PERIOD_30_DAYS = 5
  end
end